==> ejc-zjkjcost-api-3.0.0-20220622.074609-6-sources.jar: com/ejianc/business/zjkjcost/finish/vo/ApplyDetailVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-目标责任书竣工考核兑现申报-子表
 * 
 * @author generator
 * 
 */
@ApiModel("竣工考核-目标责任书竣工考核兑现申报-子表")
public class ApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("申报主表id")
    private Long applyId;
    @ApiModelProperty("单位")
    private String unit;
    @ApiModelProperty("管理目标")
    private String targetManage;
    @ApiModelProperty("目标责任")
    private String targetDuty;
    @ApiModelProperty("实现目标")
    private String targetFinish;
    @ApiModelProperty("会签意见")
    private String opinion;
    @ApiModelProperty("签名")
    private String sign;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("编辑性,1-可编辑,2-不可编辑")
    private Integer editFlag;
    

    /**
     * 申报主表id
     */
    public Long getApplyId() {
        return applyId;
    }

    /**
     * 申报主表id
     */
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 管理目标
     */
    public String getTargetManage() {
        return targetManage;
    }

    /**
     * 管理目标
     */
    public void setTargetManage(String targetManage) {
        this.targetManage = targetManage;
    }
    /**
     * 目标责任
     */
    public String getTargetDuty() {
        return targetDuty;
    }

    /**
     * 目标责任
     */
    public void setTargetDuty(String targetDuty) {
        this.targetDuty = targetDuty;
    }
    /**
     * 实现目标
     */
    public String getTargetFinish() {
        return targetFinish;
    }

    /**
     * 实现目标
     */
    public void setTargetFinish(String targetFinish) {
        this.targetFinish = targetFinish;
    }
    /**
     * 会签意见
     */
    public String getOpinion() {
        return opinion;
    }

    /**
     * 会签意见
     */
    public void setOpinion(String opinion) {
        this.opinion = opinion;
    }
    /**
     * 签名
     */
    public String getSign() {
        return sign;
    }

    /**
     * 签名
     */
    public void setSign(String sign) {
        this.sign = sign;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 编辑性,1-可编辑,2-不可编辑
     */
    public Integer getEditFlag() {
        return editFlag;
    }

    /**
     * 编辑性,1-可编辑,2-不可编辑
     */
    public void setEditFlag(Integer editFlag) {
        this.editFlag = editFlag;
    }
    
}

==> ejc-zjkjcost-api-3.0.0-20250916.085758-235-sources.jar: com/ejianc/business/zjkjcost/finish/vo/ApplyDetailVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-目标责任书竣工考核兑现申报-子表
 *
 * @author generator
 *
 */
@ApiModel("竣工考核-目标责任书竣工考核兑现申报-子表")
public class ApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("申报主表id")
    private Long applyId;
    @ApiModelProperty("单位")
    private String unit;
    @ApiModelProperty("管理目标")
    private String targetManage;
    @ApiModelProperty("目标责任")
    private String targetDuty;
    @ApiModelProperty("实现目标")
    private String targetFinish;
    @ApiModelProperty("会签意见")
    private String opinion;
    @ApiModelProperty("签名")
    private String sign;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("编辑性,1-可编辑,2-不可编辑")
    private Integer editFlag;
    @ApiModelProperty("是否为预置内容,0：否,1：是")
    private Integer initFlag;


    /**
     * 申报主表id
     */
    public Long getApplyId() {
        return applyId;
    }

    /**
     * 申报主表id
     */
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 管理目标
     */
    public String getTargetManage() {
        return targetManage;
    }

    /**
     * 管理目标
     */
    public void setTargetManage(String targetManage) {
        this.targetManage = targetManage;
    }
    /**
     * 目标责任
     */
    public String getTargetDuty() {
        return targetDuty;
    }

    /**
     * 目标责任
     */
    public void setTargetDuty(String targetDuty) {
        this.targetDuty = targetDuty;
    }
    /**
     * 实现目标
     */
    public String getTargetFinish() {
        return targetFinish;
    }

    /**
     * 实现目标
     */
    public void setTargetFinish(String targetFinish) {
        this.targetFinish = targetFinish;
    }
    /**
     * 会签意见
     */
    public String getOpinion() {
        return opinion;
    }

    /**
     * 会签意见
     */
    public void setOpinion(String opinion) {
        this.opinion = opinion;
    }
    /**
     * 签名
     */
    public String getSign() {
        return sign;
    }

    /**
     * 签名
     */
    public void setSign(String sign) {
        this.sign = sign;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 编辑性,1-可编辑,2-不可编辑
     */
    public Integer getEditFlag() {
        return editFlag;
    }

    /**
     * 编辑性,1-可编辑,2-不可编辑
     */
    public void setEditFlag(Integer editFlag) {
        this.editFlag = editFlag;
    }

    public Integer getInitFlag() {
        return initFlag;
    }

    public void setInitFlag(Integer initFlag) {
        this.initFlag = initFlag;
    }
}
